@@ -271,10 +271,14 @@ class UpdateManager(Gtk.Window):
                 self.oem_metapackages.add(pkg)
 
     def _fetch_ua_updates(self):
-        self.ua_updates = ua.updates().updates
+        try:
+            self.ua_updates = ua.updates().updates
+        except:
+            self.ua_updates = []
 
     def _get_ua_security_status(self):
         self.ua_security_packages = []
+        self.ua_updates = []
         t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
         t.start()
         while t.is_alive():
